FunctionCodeHandler

Trait FunctionCodeHandler 

pub trait FunctionCodeHandler: Send + Sync {
    // Required methods
    fn handle(&self, req: &FunctionCodeRequest) -> FunctionCodeResponse;
    fn function_code(&self) -> u8;
    fn description(&self) -> &str;
}
Trait for objects that can handle a specific Modbus function code.

Required Methods

fn handle(&self, req: &FunctionCodeRequest) -> FunctionCodeResponse

Process the request and return a response.

fn function_code(&self) -> u8

The Modbus function code byte this handler is responsible for.

fn description(&self) -> &str

Short textual description of what this handler does.

Implementors